@@ -1,4 +1,4 @@
-ddalphaf.train <- function(dataf, labels, 
+ddalphaf.train <- function(dataf, labels, subset,
                            adc.args = list(instance = "avr", 
                                            numFcn = -1, 
                                            numDer = -1), 
@@ -26,9 +26,14 @@ ddalphaf.train <- function(dataf, labels,
             is.vector(df$args) && is.vector(df$vals) &&
             is.numeric(df$args) && is.numeric(df$vals) &&
             length(df$args) == length(df$vals) &&
-            sort(df$args) == df$args))
+            is.sorted(df$args)))
       stop("Argument 'dataf' must be a list containing lists (functions) of two vectors of equal length, named 'args' and 'vals': arguments sorted in ascending order and corresponding them values respectively")
   
+  if(!missing(subset)) {
+    dataf = dataf[subset]
+    labels = labels[subset]
+  }
+  
   # Check "labels"
   if (!(length(dataf)==length(labels) && length(unique(labels))>=2))
     stop("Argument 'labels' has wrong format")
@@ -114,7 +119,7 @@ ddalphaf.train <- function(dataf, labels,
   return (ddalphaf)
 }
 
-ddalphaf.classify <- function(ddalphaf, objectsf, ...){
+ddalphaf.classify <- function(ddalphaf, objectsf, subset, ...){
   # Classifies functions
   # Args:
   #   objectsf: sample to classify, a list containing lists (functions) of 
@@ -131,13 +136,18 @@ ddalphaf.classify <- function(ddalphaf, objectsf, ...){
   if (!is.null(objectsf$args)){
     objectsf = list(objectsf) # there was a single element 
   }
+  
+  if(!missing(subset)) {
+    objectsf = objectsf[subset]
+  }
+  
   for (df in objectsf)
     if (!(is.list(df) && length(df) == 2 &&
             !is.null(df$args) && !is.null(df$vals) &&
             is.vector(df$args) && is.vector(df$vals) &&
             is.numeric(df$args) && is.numeric(df$vals) &&
             length(df$args) == length(df$vals) &&
-            sort(df$args) == df$args))
+            is.sorted(df$args)))
       stop("Argument 'objectsf' must be a list containing lists (functions) of two vectors of equal length, named 'args' and 'vals': arguments sorted in ascending order and corresponding them values respectively")
 
   # Prepare to multivariate classification
@@ -180,8 +190,8 @@ ddalphaf.classify <- function(ddalphaf, objectsf, ...){
   return (classes)
 }
 
-predict.ddalphaf <- function(object, objectsf, ...){
-  return(ddalphaf.classify(object, objectsf, ...))
+predict.ddalphaf <- function(object, objectsf, subset, ...){
+  return(ddalphaf.classify(object, objectsf, subset, ...))
 }
 
 is.in.convexf <- function(objectsf, dataf, cardinalities, 
